@@ -20,7 +20,7 @@
 
 #undef LOCAL_DEBUG
 
-static char linc_tmpdir [PATH_MAX] = "";
+static char *linc_tmpdir = NULL;
 
 /*
  * make_local_tmpdir:
@@ -82,9 +82,8 @@ make_local_tmpdir (const char *dirname)
 void
 linc_set_tmpdir (const char *dir)
 {
-	strncpy (linc_tmpdir, dir, PATH_MAX);
-
-	linc_tmpdir [PATH_MAX - 1] = '\0';
+	g_free (linc_tmpdir);
+	linc_tmpdir = g_strdup (dir);
 
 	make_local_tmpdir (linc_tmpdir);
 }
@@ -101,7 +100,7 @@ linc_set_tmpdir (const char *dir)
 char *
 linc_get_tmpdir (void)
 {
-	return g_strdup (linc_tmpdir);
+	return g_strdup (linc_tmpdir ? linc_tmpdir : "");
 }
 
 #ifdef HAVE_SOCKADDR_SA_LEN
@@ -113,10 +112,14 @@ linc_get_tmpdir (void)
 
 #if defined(AF_INET6) && defined(RES_USE_INET6)
 #define LINC_RESOLV_SET_IPV6     _res.options |= RES_USE_INET6
+#define LINC_RESOLV_UNSET_IPV6   _res.options &= ~RES_USE_INET6
 #else
 #define LINC_RESOLV_SET_IPV6
+#define LINC_RESOLV_UNSET_IPV6
 #endif
 
+
+
 #if defined(AF_INET) || defined(AF_INET6) || defined (AF_UNIX)
 const char *
 linc_get_local_hostname (void)
@@ -284,18 +287,27 @@ linc_protocol_get_sockaddr_ipv4 (const LINCProtocolInfo *proto,
 	saddr->sin_port   = htons (atoi (portnum));
 
 	if ((saddr->sin_addr.s_addr = inet_addr (hostname)) == INADDR_NONE) {
+	        int i;
 
-		LINC_RESOLV_SET_IPV6;
+		LINC_RESOLV_UNSET_IPV6;
 		if (!(_res.options & RES_INIT))
 			res_init();
 		
 		host = gethostbyname (hostname);
-		if (!host ||
-		    !ipv4_addr_from_addr (&saddr->sin_addr,
-					  (guint8 *)host->h_addr_list [0],
-					  host->h_length)) {
-			g_free (saddr);
-			return NULL;
+		if (!host) {
+		  g_free (saddr);
+		  return NULL;
+		}
+
+		for(i = 0; host->h_addr_list[i]; i++)
+		    if(ipv4_addr_from_addr (&saddr->sin_addr,
+					    (guint8 *)host->h_addr_list [i],
+					    host->h_length))
+		      break;
+
+		if(!host->h_addr_list[i]) {
+		  g_free (saddr);
+		  return NULL;
 		}
 	}
 
@@ -400,10 +412,12 @@ linc_protocol_get_sockaddr_unix (const LINCProtocolInfo *proto,
 
 		gettimeofday (&t, NULL);
 		g_snprintf (buf, sizeof (buf),
-			    "%s/linc-%x-%x-%x%x", linc_tmpdir,
-			    pid, idx++,
+			    "%s/linc-%x-%x-%x%x",
+			    linc_tmpdir ? linc_tmpdir : "",
+			    pid, idx,
 			    (guint) (rand() ^ t.tv_sec),
 			    (guint) (idx ^ t.tv_usec));
+		idx++;
 #ifdef CONNECTION_DEBUG
 		if (g_file_test (buf, G_FILE_TEST_EXISTS))
 			g_warning ("'%s' already exists !", buf);
